# PyScratch 
For more information, see: https://kwdchan.github.io/pyscratch/






## Change History

### 07 Sep 2025
**v1.0.3**  
Added undeclared dependency: Pillow   
Specified the versions of the dependencies

### Jul 2025
**v1.0.0**  
The first version
